﻿using System;
using System.ComponentModel;
using Wisej.Web;

namespace Wisej.DGVSyncSample
{
	public class DataGridViewWithBottomRows : DataGridView
	{
		private DataGridView childGrid;

		public DataGridViewWithBottomRows()
		{
			InitializeComponent();
		}

		[Browsable(false)]
		public DataGridView SummaryGrid
		{
			get { return this.childGrid;  }
		}

		protected override void OnColumnAdded(DataGridViewColumnEventArgs e)
		{
			var col = (DataGridViewColumn)e.Column.Clone();
			col.ReadOnly = true;
			col.Frozen = e.Column.Frozen;

			this.childGrid.Columns.Add(col);

			base.OnColumnAdded(e);
		}

		protected override void OnColumnWidthChanged(DataGridViewColumnEventArgs e)
		{
			this.childGrid.Columns[e.Column.Index].Width = e.Column.Width;

			base.OnColumnWidthChanged(e);
		}

		protected override void OnColumnStateChanged(DataGridViewColumnStateChangedEventArgs e)
		{
			if (e.StateChanged.HasFlag(DataGridViewElementStates.Frozen))
				this.childGrid.Columns[e.Column.Index].Frozen = e.Column.Frozen;

			base.OnColumnStateChanged(e);
		}

		protected override void OnColumnDisplayIndexChanged(DataGridViewColumnEventArgs e)
		{
			this.childGrid.Columns[e.Column.Index].DisplayIndex = e.Column.DisplayIndex;

			base.OnColumnDisplayIndexChanged(e);
		}

		protected override void OnColumnRemoved(DataGridViewColumnEventArgs e)
		{
			this.childGrid.Columns.RemoveAt(e.Column.Index);

			base.OnColumnRemoved(e);
		}

		private void InitializeComponent()
		{
			System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(DataGridViewWithBottomRows));
			this.childGrid = new Wisej.Web.DataGridView();
			((System.ComponentModel.ISupportInitialize)(this.childGrid)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this)).BeginInit();
			this.SuspendLayout();
			// 
			// childGrid
			// 
			this.childGrid.BorderStyle = Wisej.Web.BorderStyle.None;
			this.childGrid.ColumnHeadersVisible = false;
			this.childGrid.CssStyle = "border-top: 2px solid #BDBFBF";
			this.childGrid.Dock = Wisej.Web.DockStyle.Bottom;
			this.childGrid.Location = new System.Drawing.Point(0, 399);
			this.childGrid.Name = "childGrid";
			this.childGrid.ResizableEdges = Wisej.Web.AnchorStyles.Top;
			this.childGrid.ScrollBars = Wisej.Web.ScrollBars.None;
			this.childGrid.Size = new System.Drawing.Size(555, 33);
			this.childGrid.TabIndex = 0;
			// 
			// DataGridViewWithBottomRows
			// 
			this.Controls.Add(this.childGrid);
			this.InitScript = resources.GetString("$this.InitScript");
			this.Name = "DataGridViewWithBottomRows";
			this.Size = new System.Drawing.Size(557, 434);
			((System.ComponentModel.ISupportInitialize)(this.childGrid)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this)).EndInit();
			this.ResumeLayout(false);

		}
	}
}